#[non_exhaustive]pub enum VCSError {
NoVCS,
NotAllowedFilesFound {
dirty_files: Vec<String>,
staged_files: Vec<String>,
},
GitError(Error),
Anyhow(Error),
}Expand description
Enumerates the possible error values that can be generated by this crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoVCS
Unable to detect a version control system
NotAllowedFilesFound
Found a type of file that was not allowed. Includes listing of disallowed files found
Fields
GitError(Error)
Errors from the git2 library
Anyhow(Error)
Errors that were wrapped in anyhow by cargo_utils